Improve this Doc View Source

Specify custom behavior on keypress event.

## Directive Info

- This directive executes at priority level 0.

## Usage

- as element:

      <ng-keypress
        ng-keypress="expression">
      ...
      </ng-keypress>

- as attribute:

      <ANY
        ng-keypress="expression">
      ...
      </ANY>

### Arguments

Param | Type | Details
--- | --- | ---
ngKeypress | expression | Expression to evaluate upon keypress. (Event object is available as `$event` and can be interrogated for keyCode, altKey, etc.)

## Examples

    <input ng-keypress="count = count + 1" ng-init="count=0">
    key press count: {{count}}